<?php declare(strict_types=1);

namespace EuKit\Base;

use Infomaker\Everyware\Base\Utilities;

class AssetsHelper
{
    public static function getScriptUrl(string $fileName): string
    {
        $filePath = sprintf('/assets/dist/js/%s.%s', $fileName, is_dev() ? 'js' : 'min.js');

        if (static::existInChildTheme($filePath)) {
            return Utilities::getStaticThemeUri() . $filePath;
        }

        return '';
    }

    public static function getStyleUrl(string $fileName): string
    {
        $filePath = sprintf('/assets/dist/css/%s.%s', $fileName, is_dev() ? 'css' : 'min.css');

        if (static::existInChildTheme($filePath)) {
            return Utilities::getStaticThemeUri() . $filePath;
        }

        return '';
    }

    public static function getBaseScriptUrl(string $fileName): string
    {
        $filePath = sprintf('/assets/dist/js/%s.%s', $fileName, is_dev() ? 'js' : 'min.js');

        if (static::existInChildTheme($filePath)) {
            return '';
        }

        if (static::existInBaseTheme($filePath)) {
            return Utilities::getStaticTemplateUri() . $filePath;
        }

        return '';
    }

    public static function getBaseStyleUrl(string $fileName): string
    {
        $filePath = sprintf('/assets/dist/css/%s.%s', $fileName, is_dev() ? 'css' : 'min.css');

        if (static::existInChildTheme($filePath)) {
            return '';
        }

        if (static::existInBaseTheme($filePath)) {
            return Utilities::getStaticTemplateUri() . $filePath;
        }

        return '';
    }

    public static function existInChildTheme(string $fileName)
    {
        return file_exists(Utilities::childThemePath() . $fileName);
    }

    public static function existInBaseTheme(string $fileName)
    {
        return file_exists(Utilities::themePath() . $fileName);
    }
}
